@@ -29,8 +29,7 @@ class GerritChangeReviewer(BaseModel):
             reviewer.delete()
 
         :param input_: the DeleteReviewerInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
-          #delete-reviewer-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#delete-reviewer-input
         :return:
         """
         if input_ is None:
@@ -67,8 +66,7 @@ class GerritChangeReviewer(BaseModel):
 
         :param label:
         :param input_: the DeleteVoteInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
-          #delete-vote-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#delete-vote-input
         :return:
         """
         endpoint = self.endpoint + f"/votes/{label}"
@@ -82,7 +80,7 @@ class GerritChangeReviewers(object):
     def __init__(self, change, gerrit):
         self.change = change
         self.gerrit = gerrit
-        self.endpoint = f"/changes/{self.change}/reviewers/"
+        self.endpoint = f"/changes/{self.change}/reviewers"
 
     def list(self):
         """
@@ -90,7 +88,7 @@ class GerritChangeReviewers(object):
 
         :return:
         """
-        result = self.gerrit.get(self.endpoint)
+        result = self.gerrit.get(self.endpoint + "/")
         return GerritChangeReviewer.parse_list(result, change=self.change, gerrit=self.gerrit)
 
     def get(self, account):
@@ -101,8 +99,7 @@ class GerritChangeReviewers(object):
         :return:
         """
         result = self.gerrit.get(self.endpoint + f"/{account}")
-        if result:
-            return GerritChangeReviewer(json=result[0], change=self.change, gerrit=self.gerrit)
+        return GerritChangeReviewer(json=result[0], change=self.change, gerrit=self.gerrit)
 
     def add(self, input_):
         """
